@@ -21,17 +21,26 @@ from __future__ import annotations
 from tempfile import NamedTemporaryFile
 from typing import IO, Any
 
-from google.ads.googleads.client import GoogleAdsClient
-from google.ads.googleads.errors import GoogleAdsException
-from google.ads.googleads.v10.services.services.customer_service import CustomerServiceClient
-from google.ads.googleads.v10.services.services.google_ads_service import GoogleAdsServiceClient
-from google.ads.googleads.v10.services.types.google_ads_service import GoogleAdsRow, SearchGoogleAdsRequest
-from google.api_core.page_iterator import GRPCIterator
 from google.auth.exceptions import GoogleAuthError
 
 from airflow import AirflowException
 from airflow.compat.functools import cached_property
 from airflow.hooks.base import BaseHook
+from airflow.providers.google.ads._vendor.googleads.client import GoogleAdsClient
+from airflow.providers.google.ads._vendor.googleads.errors import GoogleAdsException
+from airflow.providers.google.ads._vendor.googleads.v12.services.services.customer_service import (
+    CustomerServiceClient,
+)
+from airflow.providers.google.ads._vendor.googleads.v12.services.services.google_ads_service import (
+    GoogleAdsServiceClient,
+)
+from airflow.providers.google.ads._vendor.googleads.v12.services.services.google_ads_service.pagers import (
+    SearchPager,
+)
+from airflow.providers.google.ads._vendor.googleads.v12.services.types.google_ads_service import (
+    GoogleAdsRow,
+)
+from airflow.providers.google.common.hooks.base_google import get_field
 
 
 class GoogleAdsHook(BaseHook):
@@ -70,10 +79,9 @@ class GoogleAdsHook(BaseHook):
     :param api_version: The Google Ads API version to use.
 
     :return: list of Google Ads Row object(s)
-    :rtype: list[GoogleAdsRow]
     """
 
-    default_api_version = "v10"
+    default_api_version = "v12"
 
     def __init__(
         self,
@@ -106,7 +114,6 @@ class GoogleAdsHook(BaseHook):
         :param query: Google Ads Query Language query.
         :param page_size: Number of results to return per page. Max 10000.
         :return: Google Ads API response, converted to Google Ads Row objects
-        :rtype: list[GoogleAdsRow]
         """
         data_proto_plus = self._search(client_ids, query, page_size, **kwargs)
         data_native_pb = [row._pb for row in data_proto_plus]
@@ -124,7 +131,6 @@ class GoogleAdsHook(BaseHook):
         :param query: Google Ads Query Language query.
         :param page_size: Number of results to return per page. Max 10000.
         :return: Google Ads API response, converted to Google Ads Row objects
-        :rtype: list[GoogleAdsRow]
         """
         return self._search(client_ids, query, page_size, **kwargs)
 
@@ -149,7 +155,7 @@ class GoogleAdsHook(BaseHook):
                 self.log.error('\tError with message "%s".', error.message)
                 if error.location:
                     for field_path_element in error.location.field_path_elements:
-                        self.log.error('\t\tOn field: %s', field_path_element.field_name)
+                        self.log.error("\t\tOn field: %s", field_path_element.field_name)
             raise
 
     @cached_property
@@ -200,8 +206,10 @@ class GoogleAdsHook(BaseHook):
         Updates google ads config with file path of the temp file containing the secret
         Note, the secret must be passed as a file path for Google Ads API
         """
-        secret_conn = self.get_connection(self.gcp_conn_id)
-        secret = secret_conn.extra_dejson["extra__google_cloud_platform__keyfile_dict"]
+        extras = self.get_connection(self.gcp_conn_id).extra_dejson
+        secret = get_field(extras, "keyfile_dict")
+        if not secret:
+            raise KeyError("secret_conn.extra_dejson does not contain keyfile_dict")
         secrets_temp.write(secret)
         secrets_temp.flush()
 
@@ -218,32 +226,25 @@ class GoogleAdsHook(BaseHook):
         :param page_size: Number of results to return per page. Max 10000.
 
         :return: Google Ads API response, converted to Google Ads Row objects
-        :rtype: list[GoogleAdsRow]
         """
         service = self._get_service
 
         iterators = []
         for client_id in client_ids:
-            request = self._get_client.get_type("SearchGoogleAdsRequest")  # type: SearchGoogleAdsRequest
-            request.customer_id = client_id
-            request.query = query
-            request.page_size = page_size
-
-            iterator = service.search(request=request)
+            iterator = service.search(request=dict(customer_id=client_id, query=query, page_size=page_size))
             iterators.append(iterator)
 
         self.log.info("Fetched Google Ads Iterators")
 
         return self._extract_rows(iterators)
 
-    def _extract_rows(self, iterators: list[GRPCIterator]) -> list[GoogleAdsRow]:
+    def _extract_rows(self, iterators: list[SearchPager]) -> list[GoogleAdsRow]:
         """
         Convert Google Page Iterator (GRPCIterator) objects to Google Ads Rows
 
         :param iterators: List of Google Page Iterator (GRPCIterator) objects
 
         :return: API response for all clients in the form of Google Ads Row object(s)
-        :rtype: list[GoogleAdsRow]
         """
         try:
             self.log.info("Extracting data from returned Google Ads Iterators")
