@@ -39,7 +39,7 @@ with models.DAG(
     dag_id="example_gcp_dataflow_sql",
     start_date=datetime(2021, 1, 1),
     catchup=False,
-    tags=['example'],
+    tags=["example"],
 ) as dag_sql:
     # [START howto_operator_start_sql_job]
     start_sql = DataflowStartSqlJobOperator(
