@@ -18,6 +18,7 @@
 """This module contains a Google Cloud Vision Hook."""
 from __future__ import annotations
 
+import warnings
 from copy import deepcopy
 from typing import Any, Callable, Sequence
 
@@ -82,11 +83,10 @@ class NameDeterminer:
         :param location: Location
         :param project_id: The id of Google Cloud Vision project.
         :return: The same entity or entity with new name
-        :rtype: str
         :raises: AirflowException
         """
         entity = deepcopy(entity)
-        explicit_name = getattr(entity, 'name')
+        explicit_name = getattr(entity, "name")
         if location and entity_id:
             # Necessary parameters to construct the name are present. Checking for conflict with explicit name
             constructed_name = self.get_path(project_id, location, entity_id)
@@ -119,9 +119,9 @@ class CloudVisionHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
-    product_name_determiner = NameDeterminer('Product', 'product_id', ProductSearchClient.product_path)
+    product_name_determiner = NameDeterminer("Product", "product_id", ProductSearchClient.product_path)
     product_set_name_determiner = NameDeterminer(
-        'ProductSet', 'productset_id', ProductSearchClient.product_set_path
+        "ProductSet", "productset_id", ProductSearchClient.product_set_path
     )
 
     def __init__(
@@ -130,6 +130,10 @@ class CloudVisionHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -142,7 +146,6 @@ class CloudVisionHook(GoogleBaseHook):
         Retrieves connection to Cloud Vision.
 
         :return: Google Cloud Vision client object.
-        :rtype: google.cloud.vision_v1.ProductSearchClient
         """
         if not self._client:
             self._client = ProductSearchClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
@@ -154,7 +157,6 @@ class CloudVisionHook(GoogleBaseHook):
         Creates ImageAnnotatorClient.
 
         :return: Google Image Annotator client object.
-        :rtype: google.cloud.vision_v1.ImageAnnotatorClient
         """
         return ImageAnnotatorClient(credentials=self.get_credentials())
 
@@ -180,7 +182,7 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         parent = ProductSearchClient.location_path(project_id, location)
-        self.log.info('Creating a new ProductSet under the parent: %s', parent)
+        self.log.info("Creating a new ProductSet under the parent: %s", parent)
         response = client.create_product_set(
             parent=parent,
             product_set=product_set,
@@ -189,13 +191,13 @@ class CloudVisionHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('ProductSet created: %s', response.name if response else '')
-        self.log.debug('ProductSet created:\n%s', response)
+        self.log.info("ProductSet created: %s", response.name if response else "")
+        self.log.debug("ProductSet created:\n%s", response)
 
         if not product_set_id:
             # Product set id was generated by the API
             product_set_id = self._get_autogenerated_id(response)
-            self.log.info('Extracted autogenerated ProductSet ID from the response: %s', product_set_id)
+            self.log.info("Extracted autogenerated ProductSet ID from the response: %s", product_set_id)
 
         return product_set_id
 
@@ -215,10 +217,10 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
-        self.log.info('Retrieving ProductSet: %s', name)
+        self.log.info("Retrieving ProductSet: %s", name)
         response = client.get_product_set(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('ProductSet retrieved.')
-        self.log.debug('ProductSet retrieved:\n%s', response)
+        self.log.info("ProductSet retrieved.")
+        self.log.debug("ProductSet retrieved:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -241,12 +243,12 @@ class CloudVisionHook(GoogleBaseHook):
         product_set = self.product_set_name_determiner.get_entity_with_name(
             product_set, product_set_id, location, project_id
         )
-        self.log.info('Updating ProductSet: %s', product_set.name)
+        self.log.info("Updating ProductSet: %s", product_set.name)
         response = client.update_product_set(
             product_set=product_set, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
         )
-        self.log.info('ProductSet updated: %s', response.name if response else '')
-        self.log.debug('ProductSet updated:\n%s', response)
+        self.log.info("ProductSet updated: %s", response.name if response else "")
+        self.log.debug("ProductSet updated:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -265,9 +267,9 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
-        self.log.info('Deleting ProductSet: %s', name)
+        self.log.info("Deleting ProductSet: %s", name)
         client.delete_product_set(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('ProductSet with the name [%s] deleted.', name)
+        self.log.info("ProductSet with the name [%s] deleted.", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_product(
@@ -286,7 +288,7 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         parent = ProductSearchClient.location_path(project_id, location)
-        self.log.info('Creating a new Product under the parent: %s', parent)
+        self.log.info("Creating a new Product under the parent: %s", parent)
         response = client.create_product(
             parent=parent,
             product=product,
@@ -295,13 +297,13 @@ class CloudVisionHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Product created: %s', response.name if response else '')
-        self.log.debug('Product created:\n%s', response)
+        self.log.info("Product created: %s", response.name if response else "")
+        self.log.debug("Product created:\n%s", response)
 
         if not product_id:
             # Product id was generated by the API
             product_id = self._get_autogenerated_id(response)
-            self.log.info('Extracted autogenerated Product ID from the response: %s', product_id)
+            self.log.info("Extracted autogenerated Product ID from the response: %s", product_id)
 
         return product_id
 
@@ -321,10 +323,10 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_path(project_id, location, product_id)
-        self.log.info('Retrieving Product: %s', name)
+        self.log.info("Retrieving Product: %s", name)
         response = client.get_product(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('Product retrieved.')
-        self.log.debug('Product retrieved:\n%s', response)
+        self.log.info("Product retrieved.")
+        self.log.debug("Product retrieved:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -345,12 +347,12 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         product = self.product_name_determiner.get_entity_with_name(product, product_id, location, project_id)
-        self.log.info('Updating ProductSet: %s', product.name)
+        self.log.info("Updating ProductSet: %s", product.name)
         response = client.update_product(
             product=product, update_mask=update_mask, retry=retry, timeout=timeout, metadata=metadata
         )
-        self.log.info('Product updated: %s', response.name if response else '')
-        self.log.debug('Product updated:\n%s', response)
+        self.log.info("Product updated: %s", response.name if response else "")
+        self.log.debug("Product updated:\n%s", response)
         return MessageToDict(response)
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -369,9 +371,9 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = ProductSearchClient.product_path(project_id, location, product_id)
-        self.log.info('Deleting ProductSet: %s', name)
+        self.log.info("Deleting ProductSet: %s", name)
         client.delete_product(name=name, retry=retry, timeout=timeout, metadata=metadata)
-        self.log.info('Product with the name [%s] deleted:', name)
+        self.log.info("Product with the name [%s] deleted:", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_reference_image(
@@ -390,7 +392,7 @@ class CloudVisionHook(GoogleBaseHook):
         :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionCreateReferenceImageOperator`
         """
         client = self.get_conn()
-        self.log.info('Creating ReferenceImage')
+        self.log.info("Creating ReferenceImage")
         parent = ProductSearchClient.product_path(project=project_id, location=location, product=product_id)
 
         response = client.create_reference_image(
@@ -402,14 +404,14 @@ class CloudVisionHook(GoogleBaseHook):
             metadata=metadata,
         )
 
-        self.log.info('ReferenceImage created: %s', response.name if response else '')
-        self.log.debug('ReferenceImage created:\n%s', response)
+        self.log.info("ReferenceImage created: %s", response.name if response else "")
+        self.log.debug("ReferenceImage created:\n%s", response)
 
         if not reference_image_id:
             # Reference image  id was generated by the API
             reference_image_id = self._get_autogenerated_id(response)
             self.log.info(
-                'Extracted autogenerated ReferenceImage ID from the response: %s', reference_image_id
+                "Extracted autogenerated ReferenceImage ID from the response: %s", reference_image_id
             )
 
         return reference_image_id
@@ -424,26 +426,25 @@ class CloudVisionHook(GoogleBaseHook):
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
-    ) -> dict:
+    ) -> None:
         """
         For the documentation see:
         :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionDeleteReferenceImageOperator`
         """
         client = self.get_conn()
-        self.log.info('Deleting ReferenceImage')
+        self.log.info("Deleting ReferenceImage")
         name = ProductSearchClient.reference_image_path(
             project=project_id, location=location, product=product_id, reference_image=reference_image_id
         )
 
-        response = client.delete_reference_image(
+        client.delete_reference_image(
             name=name,
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('ReferenceImage with the name [%s] deleted.', name)
-        return MessageToDict(response)
+        self.log.info("ReferenceImage with the name [%s] deleted.", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def add_product_to_product_set(
@@ -465,13 +466,13 @@ class CloudVisionHook(GoogleBaseHook):
         product_name = ProductSearchClient.product_path(project_id, location, product_id)
         product_set_name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
 
-        self.log.info('Add Product[name=%s] to Product Set[name=%s]', product_name, product_set_name)
+        self.log.info("Add Product[name=%s] to Product Set[name=%s]", product_name, product_set_name)
 
         client.add_product_to_product_set(
             name=product_set_name, product=product_name, retry=retry, timeout=timeout, metadata=metadata
         )
 
-        self.log.info('Product added to Product Set')
+        self.log.info("Product added to Product Set")
 
     @GoogleBaseHook.fallback_to_default_project_id
     def remove_product_from_product_set(
@@ -493,13 +494,13 @@ class CloudVisionHook(GoogleBaseHook):
         product_name = ProductSearchClient.product_path(project_id, location, product_id)
         product_set_name = ProductSearchClient.product_set_path(project_id, location, product_set_id)
 
-        self.log.info('Remove Product[name=%s] from Product Set[name=%s]', product_name, product_set_name)
+        self.log.info("Remove Product[name=%s] from Product Set[name=%s]", product_name, product_set_name)
 
         client.remove_product_from_product_set(
             name=product_set_name, product=product_name, retry=retry, timeout=timeout, metadata=metadata
         )
 
-        self.log.info('Product removed from Product Set')
+        self.log.info("Product removed from Product Set")
 
     def annotate_image(
         self,
@@ -513,11 +514,11 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.annotator_client
 
-        self.log.info('Annotating image')
+        self.log.info("Annotating image")
 
         response = client.annotate_image(request=request, retry=retry, timeout=timeout)
 
-        self.log.info('Image annotated')
+        self.log.info("Image annotated")
 
         return MessageToDict(response)
 
@@ -534,11 +535,11 @@ class CloudVisionHook(GoogleBaseHook):
         """
         client = self.annotator_client
 
-        self.log.info('Annotating images')
+        self.log.info("Annotating images")
 
         response = client.batch_annotate_images(requests=requests, retry=retry, timeout=timeout)
 
-        self.log.info('Images annotated')
+        self.log.info("Images annotated")
 
         return MessageToDict(response)
 
@@ -666,7 +667,7 @@ class CloudVisionHook(GoogleBaseHook):
         try:
             name = response.name
         except AttributeError as e:
-            raise AirflowException(f'Unable to get name from response... [{response}]\n{e}')
-        if '/' not in name:
-            raise AirflowException(f'Unable to get id from name... [{name}]')
-        return name.rsplit('/', 1)[1]
+            raise AirflowException(f"Unable to get name from response... [{response}]\n{e}")
+        if "/" not in name:
+            raise AirflowException(f"Unable to get id from name... [{name}]")
+        return name.rsplit("/", 1)[1]
