@@ -374,7 +374,7 @@ class GCSToGCSOperator(BaseOperator):
 
     def _copy_file(self, hook, source_object):
         destination_object = self.destination_object or source_object
-        if self.destination_object[-1] == "/":
+        if self.destination_object and self.destination_object[-1] == "/":
             file_name = source_object.split("/")[-1]
             destination_object += file_name
         self._copy_single_object(
