@@ -14,8 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+import warnings
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.suite.hooks.drive import GoogleDriveHook
@@ -33,17 +35,13 @@ class GoogleDriveToLocalOperator(BaseOperator):
         :ref:`howto/operator:GoogleDriveToLocalOperator`
 
     :param output_file: Path to downloaded file
-    :type output_file: str
     :param folder_id: The folder id of the folder in which the Google Drive file resides
-    :type folder_id: str
     :param file_name: The name of the file residing in Google Drive
-    :type file_name: str
+    :param gcp_conn_id: The GCP connection ID to use when fetching connection info.
     :param drive_id: Optional. The id of the shared Google Drive in which the file resides.
-    :type drive_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -52,7 +50,6 @@ class GoogleDriveToLocalOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -69,9 +66,10 @@ class GoogleDriveToLocalOperator(BaseOperator):
         output_file: str,
         file_name: str,
         folder_id: str,
-        drive_id: Optional[str] = None,
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        drive_id: str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -79,12 +77,18 @@ class GoogleDriveToLocalOperator(BaseOperator):
         self.folder_id = folder_id
         self.drive_id = drive_id
         self.file_name = file_name
+        self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
-        self.log.info('Executing download: %s into %s', self.file_name, self.output_file)
+    def execute(self, context: Context):
+        self.log.info("Executing download: %s into %s", self.file_name, self.output_file)
         gdrive_hook = GoogleDriveHook(
+            gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
